
from apistar.test import _TestClient
from django.test import TestCase as DjangoTestCase

from django_apistar.wsgi import application


class TestClient(_TestClient):
    def __init__(self, *args, **kwargs):
        return super().__init__(application, 'http', 'testserver')


class TestCase(DjangoTestCase):
    client_class = TestClient

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.reverse_url = application.apistar_wsgi_app.reverse_url




from django.core.management.base import BaseCommand
from apistar.commands.run import run_wsgi

from django_apistar.wsgi import application


class Command(BaseCommand):

    def handle(self, *args, **kwargs):
        return run_wsgi(application)




import os
from importlib import import_module

from apistar import Include
from apistar.frameworks.wsgi import WSGIApp
from apistar.handlers import docs_urls, static_urls

import django
from django.conf import settings
from django.core.wsgi import get_wsgi_application
from django.contrib.staticfiles.handlers import StaticFilesHandler

os.environ.setdefault("DJANGO_SETTINGS_MODULE", "django_apistar_example.settings")
django.setup()


class DjangoAPIStarWSGIApplication:
    def __init__(self):
        routes = import_module(settings.APISTAR_ROUTE_CONF).routes

        if settings.DEBUG:
            routes.append(Include('/static', static_urls))
            routes.append(Include('/docs', docs_urls))

        self.django_wsgi_app = get_wsgi_application()
        self.apistar_wsgi_app = WSGIApp(routes=routes, settings=settings.APISTAR_SETTINGS)

    def is_allowed_django_route(self, path):
        allowed_django_routes = settings.APISTAR_SETTINGS.get('ALLOWED_DJANGO_ROUTES', [])
        path_is_contained = [route for route in allowed_django_routes if path.startswith(route)]

        if path in allowed_django_routes or path_is_contained:
            return path

    def __call__(self, environ, start_response):
        path = environ['PATH_INFO']

        if path.startswith('/static/'):
            return StaticFilesHandler(self.django_wsgi_app)(environ, start_response)

        if self.is_allowed_django_route(path):
            return self.django_wsgi_app(environ, start_response)

        return self.apistar_wsgi_app(environ, start_response)


application = DjangoAPIStarWSGIApplication()




import base64
import typing
from apistar import http
from apistar.interfaces import Auth
from django.contrib.auth import authenticate


class DjangoAuth(Auth):
    def __init__(self, user=None, *args, **kwargs):
        self.user = user
        return super().__init__(*args, **kwargs)

    def is_authenticated(self) -> bool:
        if self.user:
            return self.user.is_authenticated

    def get_display_name(self) -> typing.Optional[str]:
        if self.user:
            return self.user.username

    def get_user_id(self) -> typing.Optional[str]:
        if self.user:
            return self.user.id


class DjangoBasicAuthentication():
    def authenticate(self, authorization: http.Header):
        """
        Determine the user associated with a request, using HTTP Basic Authentication.
        """
        if authorization is None:
            return None

        scheme, token = authorization.split()
        if scheme.lower() != 'basic':
            return None

        username, password = base64.b64decode(token).decode('utf-8').split(':')
        user = authenticate(username=username, password=password)

        if user:
            return DjangoAuth(user=user)



from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='django_apistar',
    version='0.3.1',
    description='Django app for using API Star as frontend.',
    long_description=long_description,
    long_description_content_type='text/x-rst',
    url='https://github.com/lucianoratamero/django_apistar',
    author='Luciano Ratamero',
    author_email='luciano@ratamero.com',

    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django :: 1.8',
        'Framework :: Django :: 2.0',
        'License :: OSI Approved :: BSD License',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3.6',
    ],

    include_package_data=True,
    keywords='apistar api rest django',
    packages=find_packages(exclude=['tests']),
    install_requires=['django>=1.8', 'apistar>=0.3.5'],
    python_requires='>=3.6',
)
